package com.ematou.wxbase.aop;

import com.ematou.wxbase.exception.ServiceException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

/**
 * @author lhm
 * @version 1.0
 * 2021-04-30 16:30
 */
@Aspect
@Component
public class LogAspect {

    private static final Logger logger = LoggerFactory.getLogger(LogAspect.class);

    @Pointcut("execution(* com.ematou.wxbase.service.*Service.*(..))")
    public void targetMethod() {}

    @Around("targetMethod()")
    public Object around(ProceedingJoinPoint joinPoint) {
        Signature signature = joinPoint.getSignature();
        MethodSignature ms = (MethodSignature) signature;
        String targetMethodName = ms.getMethod().getName();

        ObjectMapper objectMapper = new ObjectMapper();

        Object proceed = null;
        try {
            logger.info("----------------方法: " + targetMethodName + "的参数为: " + objectMapper.writeValueAsString(joinPoint.getArgs()) + "----------------");
            proceed = joinPoint.proceed();
            logger.info("----------------方法: " + targetMethodName + "执行的返回值为: " + proceed + "----------------");
        }catch (ServiceException se){
            // 如果时业务异常记录结果，抛出交给统一异常处理
            throw se;
        } catch (Throwable throwable) {
            logger.error("----------------方法: " + targetMethodName + "执行出现异常，错误信息为：" + throwable.getMessage() + "----------------", throwable);
        }
        return proceed;
    }

}
