package com.ematou.wxbase.exception;


import cn.hutool.core.util.StrUtil;

import java.util.Objects;

/**
 * 断言类
 *
 * @author frankeleyn
 * @email lvjian@qhdswl.com
 * @date 2022/12/21 10:39
 */
public abstract class Assert {

    /**
     * 断言对象不为空
     * 如果对象obj为空，则抛出异常
     * @param obj 待判断对象
     */
    public static void notNull(Object obj, String msg) {
        if (Objects.isNull(obj)) {
            throw new ServiceException(msg);
        }
    }


    /**
     * 断言对象为空
     * 如果对象obj不为空，则抛出异常
     * @param object
     * @param msg
     */
    public static void isNull(Object object, String msg) {
        if (Objects.nonNull(object)) {
            throw new ServiceException(msg);
        }
    }

    /**
     * 断言表达式为真
     * 如果为假，则抛出异常
     *
     * @param expression 是否成功
     */
    public static void isTrue(boolean expression, String msg) {
        if (!expression) {
            throw new ServiceException(msg);
        }
    }

    /**
     * 断言表达式为假
     * 如果为真，则抛出异常
     *
     * @param expression 是否成功
     */
    public static void notTrue(boolean expression, String msg) {
        if (expression) {
            throw new ServiceException(msg);
        }
    }

    /**
     * 断言两个对象不相等
     * 如果相等，则抛出异常
     * @param m1
     * @param m2
     * @param msg
     */
    public static void notEquals(Object m1, Object m2,  String msg) {
        if (m1.equals(m2)) {
            throw new ServiceException(msg);
        }
    }

    /**
     * 断言两个对象相等
     * 如果不相等，则抛出异常
     * @param m1
     * @param m2
     * @param msg
     */
    public static void equals(Object m1, Object m2,  String msg) {
        if (!m1.equals(m2)) {
            throw new ServiceException(msg);
        }
    }

    /**
     * 断言参数不为空
     * 如果为空，则抛出异常
     * @param s
     * @param msg
     */
    public static void notEmpty(String s, String msg) {
        if (StrUtil.isBlank(s)) {
            throw new ServiceException(msg);
        }
    }
}
